import gc
import os
import moviepy.editor as mp

# process video
def processVideo(input_directory, output_directory, day, hour):
    print("preparing new hour..." + hour)
    video = getHour(input_directory + day + "/" + hour)
    video.write_videofile(output_directory + day + "_" + hour + ".mp4")
    del(video)
    gc.collect()
    print("completed processing video...")

# combine all the minutes in an hour
def getHour(hour_directory):
    #print(hour_directory)
    os.chdir(hour_directory)
    minutes = os.listdir(hour_directory)
    clips = []
    for minute in minutes:
        if minute.endswith(".mp4"):
            try:
                clips.append(mp.VideoFileClip(minute))
            except:
                pass
    video = mp.concatenate_videoclips(clips, method='compose')
    gc.collect()
    return video


from setuptools import setup, find_packages

VERSION = '0.0.6' 
DESCRIPTION = 'A python package for interacting with wyze camera video data.'
LONG_DESCRIPTION = '...'

# Setting up
setup(
       # the name must match the folder name 'verysimplemodule'
        name="wyzepy", 
        version=VERSION,
        author="Fausto Lopez",
        author_email="<youremail@email.com>",
        description=DESCRIPTION,
        long_description=LONG_DESCRIPTION,
        packages=find_packages(),
        install_requires=["moviepy"], # add any additional packages that 
        # needs to be installed along with your package. Eg: 'caer'
        
        keywords=['python', 'first package'],
        classifiers= [
            "Development Status :: 3 - Alpha",
            "Intended Audience :: Education",
            "Programming Language :: Python :: 2",
            "Programming Language :: Python :: 3",
            "Operating System :: MacOS :: MacOS X",
            "Operating System :: Microsoft :: Windows",
        ]
)